@@ -3,7 +3,7 @@
 echo ""
 echo ""
 echo "#################################################"
-echo "### HinemosDB stats collect script (20090316) ###"
+echo "### HinemosDB stats collect script (20091113) ###"
 echo "###    Script start at `date '+%Y-%m-%d %T'`    ###"
 echo "#################################################"
 echo ""
@@ -378,9 +378,9 @@ echo "### netstat -s ###"
 netstat -s
 echo -e "\n"
 
-## netstat -an
-echo "### netstat -an ###"
-netstat -an
+## netstat -anpo
+echo "### netstat -anpo ###"
+netstat -anpo
 echo -e "\n"
 
 ## df
